﻿using System.Net.Mail;
using DataLayer;
using NUnit.Framework;

namespace BusinessLayer.Tests
{
    [TestFixture]
    public class EmailServiceTests
    {
        private Bug bug;
        [SetUp]
        public void Setup()
        {
            bug = CreateBug();
        }

        private Bug CreateBug()
        {
            Bug b = new Bug();
            b.ID = 123;
            b.User = new User();
            b.User.email = "test@tester.com";
            b.Title = "Test Bug";
            return b;
        }

        [Test]
        public void CreateInsertBugMessage_ValidBug_ConstructedMailMessage()
        {
            EmailService emailService = new EmailService();
            MailMessage createdEmail = emailService.CreateInsertBugMessage(bug);

            Assert.IsNotNull(createdEmail, "Email was null");
        }

        [Test]
        public void CreateInsertBugMessage_BugWithUserAttached_UserAssignedTo()
        {
            EmailService emailService = new EmailService();
            MailMessage createdEmail = emailService.CreateInsertBugMessage(bug);
            Assert.AreEqual(bug.User.email, createdEmail.To.ToString());
        }

        [Test] //This found a problem with bug.User.email if it was null as I wasn't using shared creator
        public void CreateInsertBugMessage_BugWithUserAttached_BugIDInSubject()
        {
            EmailService emailService = new EmailService();
            MailMessage createdEmail = emailService.CreateInsertBugMessage(bug);
            Assert.IsTrue(createdEmail.Subject.Contains(bug.ID.ToString()));
        }

        [Test]
        public void CreateInsertBugMessage_BugWithoutUserAttached_NullReturned()
        {
            bug.User = null;
            EmailService emailService = new EmailService();
            MailMessage createdEmail = emailService.CreateInsertBugMessage(bug);
            Assert.IsNull(createdEmail);
        }

        [Test]
        public void CreateInsertBugMessage_ValidBug_ContainsTitleInMessageBody()
        {
            EmailService emailService = new EmailService();
            MailMessage createdEmail = emailService.CreateInsertBugMessage(bug);
            Assert.IsTrue(createdEmail.Body.Contains(bug.Title));
        }
    }
}
