﻿using System.Collections.Generic;
using System.Linq;
using DataLayer;

namespace BusinessLayer
{
    public class BugController
    {
        public IRepository<Bug> Repository { get; set; }
        IEmailService EmailService { get; set; }

        public BugController(IRepository<Bug> repository, IEmailService emailService)
        {
            Repository = repository;
            EmailService = emailService;
        }

        public Bug GetBug(int bugId)
        {
            return Repository.Find(b => b.ID == bugId);
        }

        public List<Bug> GetAllActiveBugs()
        {
            return Repository.Where(b => b.IsActive).ToList();
        }

        public bool InsertBug(Bug b)
        {
            if (IsBugValid(b) == false)
                return false;

            bool inserted = Repository.Add(b);
            if(inserted)
                EmailService.SendInsertNotification(b);

            return inserted;
        }

        public bool UpdateBug(Bug updatedBug, Bug original)
        {
            return Repository.Update(updatedBug, original);
        }

        public bool IsBugValid(Bug bug)
        {
            if (bug == null)
                return false;

            if (string.IsNullOrEmpty(bug.Title))
                return false;

            return true;
        }
    }
}
