﻿using System.Collections.Generic;
using System.Linq;
using NUnit.Framework;

namespace DataLayer.Tests
{
    [TestFixture]
    public class RepositoryTests
    {
        private Repository<Bug> repository;
        private Bug stubBug;

        [SetUp]
        public void Setup()
        {
            stubBug = new Bug { ID = 1, IsActive = true, Title = "Test" };
            DatabaseDataContext dc = new DatabaseDataContext();
            dc.Bugs.InsertOnSubmit(stubBug);
            dc.SubmitChanges();

            repository = new Repository<Bug>();

        }

        [TearDown]
        public void Teardown()
        {
            DatabaseDataContext dc = new DatabaseDataContext();
            dc.Bugs.DeleteAllOnSubmit(dc.Bugs);
            dc.SubmitChanges();
            dc.ExecuteCommand("DBCC CHECKIDENT (Bug, RESEED, 0)", new object[] { });
        }


        [Test]
        public void Add_CreatedBug_True()
        {
            bool inserted = repository.Add(new Bug {ID = 1, IsActive = true, Title = "Test"});
            Assert.IsTrue(inserted, "Bug not inserted");

            DatabaseDataContext dc = new DatabaseDataContext();
            Bug actual = (from b in dc.Bugs
                          where b.ID == 1
                          select b).First();
            Assert.IsNotNull(actual);
        }

        [Test]
        public void Find_ValidBugID_BugObject()
        {
            Bug actual = repository.Find(b => b.ID == 1);
            Assert.AreEqual(stubBug.Title, actual.Title, "Bugs are not the same");
        }

        [Test]
        public void Where_ValidBugTitle_BugListWithBug()
        {
            List<Bug> list = repository.Where(b => b.Title == "Test").ToList();
            Assert.AreEqual(1, list.Count, "Count does not equal 1");
            Assert.IsTrue(stubBug.Equals(list[0]), "Bugs are not equal");
        }

        [Test]
        public void Update_InsertedBug_SetIsValidFalse_ReturnsTrue()
        {
            Bug n = new Bug();
            n.ID = 1;
            n.Title = "Test";
            n.IsActive = false;
            n.User = null;

            bool result = repository.Update(n, stubBug);

            Assert.IsTrue(result);
        }

        [Test]
        public void Update_SetIsValidFalse_UpdatesDatabase()
        {
            Bug n = new Bug();
            n.ID = 1;
            n.Title = "Test";
            n.IsActive = false;
            n.User = null;

            bool result = repository.Update(n, stubBug);

            DatabaseDataContext dc = new DatabaseDataContext();
            Bug actual = (from b in dc.Bugs
                          where b.ID == 1
                          select b).First();

            Assert.AreEqual(n.ID, actual.ID);
            Assert.AreEqual(n.Title, actual.Title);
            Assert.IsFalse(actual.IsActive);
        }
    }
}
